@@ -18,7 +18,7 @@ fn navigation_benchmark(c: &mut Criterion) {
     });
 
     let lua = mlua::Lua::new();
-    let mut app = app::App::create(PWD.into(), &lua).expect("failed to create app");
+    let mut app = app::App::create(PWD.into(), &lua, None).expect("failed to create app");
 
     app = app
         .clone()
@@ -96,7 +96,7 @@ fn draw_benchmark(c: &mut Criterion) {
     });
 
     let lua = mlua::Lua::new();
-    let mut app = app::App::create(PWD.into(), &lua).expect("failed to create app");
+    let mut app = app::App::create(PWD.into(), &lua, None).expect("failed to create app");
 
     app = app
         .clone()
