@@ -1,7 +1,6 @@
 #![allow(clippy::too_many_arguments)]
 
 use crate::app;
-use crate::auto_refresher;
 use crate::event_reader;
 use crate::explorer;
 use crate::lua;
@@ -87,6 +86,16 @@ fn call(app: &app::App, cmd: app::Command, silent: bool) -> io::Result<ExitStatu
         .status()
 }
 
+fn start_fifo(path: &str, focus_path: &str) -> Result<fs::File> {
+    match fs::OpenOptions::new().write(true).open(path) {
+        Ok(mut file) => {
+            writeln!(file, "{}", focus_path)?;
+            Ok(file)
+        }
+        Err(e) => Err(e.into()),
+    }
+}
+
 pub struct Runner {
     pwd: PathBuf,
     focused_path: Option<PathBuf>,
@@ -97,12 +106,15 @@ pub struct Runner {
 
 impl Runner {
     pub(crate) fn new(path: Option<PathBuf>) -> Result<Self> {
-        let mut pwd = path.unwrap_or_else(|| ".".into()).canonicalize()?;
+        let basedir = std::env::current_dir()?;
+        let mut pwd = path
+            .map(|p| if p.is_relative() { basedir.join(p) } else { p })
+            .unwrap_or_else(|| basedir.clone());
         let mut focused_path = None;
 
         if pwd.is_file() {
             focused_path = pwd.file_name().map(|p| p.into());
-            pwd = pwd.parent().map(|p| p.into()).unwrap_or_else(|| ".".into());
+            pwd = pwd.parent().map(|p| p.into()).unwrap_or(basedir);
         }
 
         Ok(Self {
@@ -165,11 +177,25 @@ impl Runner {
         let session_path = app.session_path().to_owned();
 
         term::enable_raw_mode()?;
+
+        // Use a tty to enable piping results
         let mut stdout = get_tty()?;
+        // let stdout = io::stdout();
         // let mut stdout = stdout.lock();
         execute!(stdout, term::EnterAlternateScreen)?;
 
-        let mut fifo: Option<fs::File> = None;
+        let mut fifo: Option<fs::File> = if let Some(path) = app.config().general().start_fifo() {
+            match start_fifo(&path, &app.focused_node_str()) {
+                Ok(file) => Some(file),
+                Err(e) => {
+                    app = app.log_error(e.to_string())?;
+                    None
+                }
+            }
+        } else {
+            None
+        };
+
         let mut last_focus: Option<app::Node> = None;
 
         let mut mouse_enabled = app.config().general().enable_mouse();
@@ -184,10 +210,8 @@ impl Runner {
         terminal.hide_cursor()?;
 
         // Threads
-        auto_refresher::start_auto_refreshing(tx_msg_in.clone());
         event_reader::keep_reading(tx_msg_in.clone(), rx_event_reader);
         pwd_watcher::keep_watching(app.pwd(), tx_msg_in.clone(), rx_pwd_watcher)?;
-        // pipe_reader::keep_reading(app.pipe().msg_in().clone(), tx_msg_in.clone());
 
         // Enqueue on_load messages
         for msg in self.on_load {
@@ -327,15 +351,11 @@ impl Runner {
                             }
 
                             app::MsgOut::StartFifo(path) => {
-                                if let Some(file) = fifo {
-                                    fifo = None;
-                                    std::mem::drop(file);
-                                }
-
-                                match fs::OpenOptions::new().write(true).open(path) {
-                                    Ok(file) => fifo = Some(file),
+                                fifo = match start_fifo(&path, &app.focused_node_str()) {
+                                    Ok(file) => Some(file),
                                     Err(e) => {
                                         app = app.log_error(e.to_string())?;
+                                        None
                                     }
                                 }
                             }
@@ -352,10 +372,11 @@ impl Runner {
                                     fifo = None;
                                     std::mem::drop(file);
                                 } else {
-                                    match fs::OpenOptions::new().write(true).open(path) {
-                                        Ok(file) => fifo = Some(file),
+                                    fifo = match start_fifo(&path, &app.focused_node_str()) {
+                                        Ok(file) => Some(file),
                                         Err(e) => {
                                             app = app.log_error(e.to_string())?;
+                                            None
                                         }
                                     }
                                 }
@@ -544,7 +565,7 @@ impl Runner {
         term::disable_raw_mode()?;
         terminal.show_cursor()?;
 
-        fs::remove_dir(session_path)?;
+        fs::remove_dir_all(session_path)?;
 
         result
     }
